==> qmmp-1.7.9.tar.bz2: qmmp-1.7.9/src/plugins/Input/xmp/translations/xmp_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="39"/>
        <source>XMP Plugin</source>
        <translation>XMP插件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="54"/>
        <source>Module Files</source>
        <translation>模块文件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="109"/>
        <source>About XMP Audio Plugin</source>
        <translation>关于XMP音频插件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Qmmp XMP音频插件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Compiled against libxmp-%1</source>
        <translation>对照libxmp-%1进行了编译</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="51"/>
        <source>Volume scale</source>
        <translation>音量范围</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="52"/>
        <source>Number of patterns</source>
        <translation>样式数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Number of tracks</source>
        <translation>音轨数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Tracks per pattern</source>
        <translation>每种样式的音轨</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Number of instruments</source>
        <translation>乐器数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of samples</source>
        <translation>样品数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Initial speed</source>
        <translation>初始速度</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Initial BPM</source>
        <translation>初始BPM（每分钟拍数）</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Module length in patterns</source>
        <translation>样式中的模长</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="79"/>
        <source>Samples</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="87"/>
        <source>Instruments</source>
        <translation>乐器</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="92"/>
        <source>Comment</source>
        <translation>评论</translation>
    </message>
</context>
<context>
    <name>XmpSettingsDialog</name>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>XMP插件设置</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="34"/>
        <source>Amplification factor:</source>
        <translation>扩音比率：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>立体声混合：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>插音类型：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>低音通过过滤效果</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>使用vblank时间管理</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>模拟Protracker 2.x FX9问题</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>取样率：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="109"/>
        <source>Emulate sample loop bug</source>
        <translation>模拟循环样本错误</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="116"/>
        <source>Use Paula mixer in Amiga modules</source>
        <translation>在 Amiga 模块中使用 Paula 混音器</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100赫兹</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000赫兹</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>最近的邻居</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>线性</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>三次样条</translation>
    </message>
</context>
</TS>

==> qmmp_2.2.8.orig.tar.bz2: qmmp-2.2.8/src/plugins/Input/xmp/translations/xmp_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="39"/>
        <source>XMP Plugin</source>
        <translation>XMP插件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="54"/>
        <source>Module Files</source>
        <translation>模块文件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="109"/>
        <source>About XMP Audio Plugin</source>
        <translation>关于XMP音频插件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Qmmp XMP音频插件</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Compiled against libxmp-%1</source>
        <translation>对照libxmp-%1进行了编译</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="51"/>
        <source>Volume scale</source>
        <translation>音量范围</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="52"/>
        <source>Number of patterns</source>
        <translation>样式数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Number of tracks</source>
        <translation>音轨数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Tracks per pattern</source>
        <translation>每种样式的音轨</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Number of instruments</source>
        <translation>乐器数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of samples</source>
        <translation>样品数量</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Initial speed</source>
        <translation>初始速度</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Initial BPM</source>
        <translation>初始BPM（每分钟拍数）</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Module length in patterns</source>
        <translation>样式中的模长</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="79"/>
        <source>Samples</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="87"/>
        <source>Instruments</source>
        <translation>乐器</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="92"/>
        <source>Comment</source>
        <translation>评论</translation>
    </message>
</context>
<context>
    <name>XmpSettingsDialog</name>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>XMP插件设置</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="34"/>
        <source>Amplification factor:</source>
        <translation>扩音比率：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>立体声混合：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>插音类型：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>低音通过过滤效果</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>使用vblank时间管理</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>模拟Protracker 2.x FX9问题</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>取样率：</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="109"/>
        <source>Emulate sample loop bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="116"/>
        <source>Use Paula mixer in Amiga modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100赫兹</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000赫兹</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>最近的邻居</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>线性</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>三次样条</translation>
    </message>
</context>
</TS>
